require 'thor'
require 'clipboard'

module Jsonip
  class CLI < Thor
    class_option :quiet, :type => :boolean, :aliases => [ '-q', '-s', '--silent' ], :desc => 'Prints minimal output. Useful for shell scripts and pipes'

    desc "script", "Like print --quiet. Useful for shell scripts and pipes."
    def script
      say json_ip
    end

    desc "print", "Prints your IP, but dont copy"
    def print
      say print_message
    end

    desc "copy", "Copy your IP to clipboard"
    def copy
      copy_to_clipboard
      say copy_message unless options.quiet?
    end

    desc "version", "Prints #{$0} version"
    def version
      say VERSION
    end

    protected

    def print_message
      "".tap do |msg|
        msg << yellow("Your IP is: ") unless options.quiet?
        msg << formated_ip
      end
    end

    def copy_message
      prefix = yellow("Your IP address")
      sufix = yellow("was copied to clipboard")

      [ prefix, formated_ip, sufix ].join(" ")
    end

    def yellow(text)
      set_color(text, :yellow)
    end

    def copy_to_clipboard
      Clipboard.copy json_ip
    end

    def formated_ip
      options.quiet? ? json_ip : set_color(json_ip, :white, :bold)
    end

    def json_ip
      @json_ip ||= Jsonip.get
    end
  end
end
